==> orthanc-webviewer_2.4-3.debian.tar.xz: Orthanc-1.3.2/Core/Compression/DeflateBaseCompressor.cpp <==
/**
 * Orthanc - A Lightweight, RESTful DICOM Store
 * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
 * Department, University Hospital of Liege, Belgium
 * Copyright (C) 2017-2018 Osimis S.A., Belgium
 *
 * This program is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * In addition, as a special exception, the copyright holders of this
 * program give permission to link the code of its release with the
 * OpenSSL project's "OpenSSL" library (or with modified versions of it
 * that use the same license as the "OpenSSL" library), and distribute
 * the linked executables. You must obey the GNU General Public License
 * in all respects for all of the code used other than "OpenSSL". If you
 * modify file(s) with this exception, you may extend this exception to
 * your version of the file(s), but you are not obligated to do so. If
 * you do not wish to do so, delete this exception statement from your
 * version. If you delete this exception statement from all source files
 * in the program, then also delete it here.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 **/


#include "../PrecompiledHeaders.h"
#include "DeflateBaseCompressor.h"

#include "../OrthancException.h"
#include "../Logging.h"

#include <string.h>

namespace Orthanc
{
  void DeflateBaseCompressor::SetCompressionLevel(uint8_t level)
  {
    if (level >= 10)
    {
      LOG(ERROR) << "Zlib compression level must be between 0 (no compression) and 9 (highest compression)";
      throw OrthancException(ErrorCode_ParameterOutOfRange);
    }

    compressionLevel_ = level;
  }


  uint64_t DeflateBaseCompressor::ReadUncompressedSizePrefix(const void* compressed,
                                                             size_t compressedSize)
  {
    if (compressedSize == 0)
    {
      return 0;
    }

    if (compressedSize < sizeof(uint64_t))
    {
      LOG(ERROR) << "The compressed buffer is ill-formed";
      throw OrthancException(ErrorCode_CorruptedFile);
    }

    uint64_t size;
    memcpy(&size, compressed, sizeof(uint64_t));

    return size;
  }

}

==> orthanc-webviewer_2.6-1.debian.tar.xz: Orthanc-1.7.0/Core/Compression/DeflateBaseCompressor.cpp <==
/**
 * Orthanc - A Lightweight, RESTful DICOM Store
 * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
 * Department, University Hospital of Liege, Belgium
 * Copyright (C) 2017-2020 Osimis S.A., Belgium
 *
 * This program is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * In addition, as a special exception, the copyright holders of this
 * program give permission to link the code of its release with the
 * OpenSSL project's "OpenSSL" library (or with modified versions of it
 * that use the same license as the "OpenSSL" library), and distribute
 * the linked executables. You must obey the GNU General Public License
 * in all respects for all of the code used other than "OpenSSL". If you
 * modify file(s) with this exception, you may extend this exception to
 * your version of the file(s), but you are not obligated to do so. If
 * you do not wish to do so, delete this exception statement from your
 * version. If you delete this exception statement from all source files
 * in the program, then also delete it here.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 **/


#include "../PrecompiledHeaders.h"
#include "DeflateBaseCompressor.h"

#include "../OrthancException.h"
#include "../Logging.h"

#include <string.h>

namespace Orthanc
{
  void DeflateBaseCompressor::SetCompressionLevel(uint8_t level)
  {
    if (level >= 10)
    {
      throw OrthancException(ErrorCode_ParameterOutOfRange,
                             "Zlib compression level must be between 0 (no compression) and 9 (highest compression)");
    }

    compressionLevel_ = level;
  }


  uint64_t DeflateBaseCompressor::ReadUncompressedSizePrefix(const void* compressed,
                                                             size_t compressedSize)
  {
    if (compressedSize == 0)
    {
      return 0;
    }

    if (compressedSize < sizeof(uint64_t))
    {
      throw OrthancException(ErrorCode_CorruptedFile, "The compressed buffer is ill-formed");
    }

    uint64_t size;
    memcpy(&size, compressed, sizeof(uint64_t));

    return size;
  }

}
